KannadaImage2Text is a package which uses tesseract ocr in the backend to convert the kannada text in jpg/pdf files to editable format. A Special feature of this is it can separate columns in the page and thus making it easier to read and edit. Do consider using this package if necessary and feel free to mail me for any clarifications.

